MINOR: channel/stconn: Replace channel_shutw_now() by sc_schedule_shutdown()

After the flag renaming, it is now the turn for the channel function to be
renamed and moved in the SC scope. channel_shutw_now() is replaced by
sc_schedule_shutdown(). The request channel is replaced by the front SC and
the response is replace by the back SC.
diff --git a/src/stconn.c b/src/stconn.c
index 87529aa..8e1759e 100644
--- a/src/stconn.c
+++ b/src/stconn.c
@@ -511,11 +511,11 @@
 		return 0;
 
 	if (!channel_is_empty(sc_ic(sc))) {
 		/* the close to the write side cannot be forwarded now because
 		 * we should flush outgoing data first. But instruct the output
 		 * channel it should be done ASAP.
 		 */
-		channel_shutw_now(sc_oc(sc));
+		sc_schedule_shutdown(sc);
 		return 0;
 	}
 
@@ -1484,7 +1484,7 @@
 	if (sc_ep_test(sc, SE_FL_EOS)) {
 		/* we received a shutdown */
 		if (ic->flags & CF_AUTO_CLOSE)
-			channel_shutw_now(ic);
+			sc_schedule_shutdown(sc_opposite(sc));
 		sc_conn_read0(sc);
 		ret = 1;
 	}
@@ -1777,7 +1777,7 @@
 	if (sc_ep_test(sc, SE_FL_EOS) && !(sc->flags & SC_FL_SHUTR)) {
 		/* we received a shutdown */
 		if (ic->flags & CF_AUTO_CLOSE)
-			channel_shutw_now(ic);
+			sc_schedule_shutdown(sc_opposite(sc));
 		sc_conn_read0(sc);
 	}
@@ -511,11 +511,11 @@
 
 	if (!channel_is_empty(sc_ic(sc))) {
-		/* the close to the write side cannot be forwarded now because
+		/* the shutdown cannot be forwarded now because
 		 * we should flush outgoing data first. But instruct the output
 		 * channel it should be done ASAP.